"""InfluxDBClient is client for API defined in https://github.com/influxdata/influxdb/blob/master/http/swagger.yml."""

from __future__ import absolute_import

import logging
import warnings

from influxdb_client import HealthCheck, HealthService, Ready, ReadyService, PingService, \
    InvokableScriptsApi
from influxdb_client.client._base import _BaseClient
from influxdb_client.client.authorizations_api import AuthorizationsApi
from influxdb_client.client.bucket_api import BucketsApi
from influxdb_client.client.delete_api import DeleteApi
from influxdb_client.client.labels_api import LabelsApi
from influxdb_client.client.organizations_api import OrganizationsApi
from influxdb_client.client.query_api import QueryApi, QueryOptions
from influxdb_client.client.tasks_api import TasksApi
from influxdb_client.client.users_api import UsersApi
from influxdb_client.client.write_api import WriteApi, WriteOptions, PointSettings

logger = logging.getLogger('influxdb_client.client.influxdb_client')


class InfluxDBClient(_BaseClient):
    """InfluxDBClient is client for InfluxDB v2."""

    def __init__(self, url, token: str = None, debug=None, timeout=10_000, enable_gzip=False, org: str = None,
                 default_tags: dict = None, **kwargs) -> None:
        """
        Initialize defaults.

        :param url: InfluxDB server API url (ex. http://localhost:8086).
        :param token: ``token`` to authenticate to the InfluxDB API
        :param debug: enable verbose logging of http requests
        :param timeout: HTTP client timeout setting for a request specified in milliseconds.
                        If one number provided, it will be total request timeout.
                        It can also be a pair (tuple) of (connection, read) timeouts.
        :param enable_gzip: Enable Gzip compression for http requests. Currently, only the "Write" and "Query" endpoints
                            supports the Gzip compression.
        :param org: organization name (used as a default in Query, Write and Delete API)
        :key bool verify_ssl: Set this to false to skip verifying SSL certificate when calling API from https server.
        :key str ssl_ca_cert: Set this to customize the certificate file to verify the peer.
        :key str cert_file: Path to the certificate that will be used for mTLS authentication.
        :key str cert_key_file: Path to the file contains private key for mTLS certificate.
        :key str cert_key_password: String or function which returns password for decrypting the mTLS private key.
        :key ssl.SSLContext ssl_context: Specify a custom Python SSL Context for the TLS/ mTLS handshake.
                                         Be aware that only delivered certificate/ key files or an SSL Context are
                                         possible.
        :key str proxy: Set this to configure the http proxy to be used (ex. http://localhost:3128)
        :key str proxy_headers: A dictionary containing headers that will be sent to the proxy. Could be used for proxy
                                authentication.
        :key int connection_pool_maxsize: Number of connections to save that can be reused by urllib3.
                                          Defaults to "multiprocessing.cpu_count() * 5".
        :key urllib3.util.retry.Retry retries: Set the default retry strategy that is used for all HTTP requests
                                               except batching writes. As a default there is no one retry strategy.
        :key bool auth_basic: Set this to true to enable basic authentication when talking to a InfluxDB 1.8.x that
                              does not use auth-enabled but is protected by a reverse proxy with basic authentication.
                              (defaults to false, don't set to true when talking to InfluxDB 2)
        :key str username: ``username`` to authenticate via username and password credentials to the InfluxDB 2.x
        :key str password: ``password`` to authenticate via username and password credentials to the InfluxDB 2.x
        :key list[str] profilers: list of enabled Flux profilers
        """
        super().__init__(url=url, token=token, debug=debug, timeout=timeout, enable_gzip=enable_gzip, org=org,
                         default_tags=default_tags, http_client_logger="urllib3", **kwargs)

        from .._sync.api_client import ApiClient
        self.api_client = ApiClient(configuration=self.conf, header_name=self.auth_header_name,
                                    header_value=self.auth_header_value, retries=self.retries)

    def __enter__(self):
        """
        Enter the runtime context related to this object.

        It will bind this method’s return value to the target(s)
        specified in the `as` clause of the statement.

        return: self instance
        """
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        """Exit the runtime context related to this object and close the client."""
        self.close()

    @classmethod
    def from_config_file(cls, config_file: str = "config.ini", debug=None, enable_gzip=False, **kwargs):
        """
        Configure client via configuration file. The configuration has to be under 'influx' section.

        :param config_file: Path to configuration file
        :param debug: Enable verbose logging of http requests
        :param enable_gzip: Enable Gzip compression for http requests. Currently, only the "Write" and "Query" endpoints
                            supports the Gzip compression.
        :key config_name: Name of the configuration section of the configuration file
        :key str proxy_headers: A dictionary containing headers that will be sent to the proxy. Could be used for proxy
                                authentication.
        :key urllib3.util.retry.Retry retries: Set the default retry strategy that is used for all HTTP requests
                                               except batching writes. As a default there is no one retry strategy.
        :key ssl.SSLContext ssl_context: Specify a custom Python SSL Context for the TLS/ mTLS handshake.
                                         Be aware that only delivered certificate/ key files or an SSL Context are
                                         possible.

        The supported formats:
            - https://docs.python.org/3/library/configparser.html
            - https://toml.io/en/
            - https://www.json.org/json-en.html

        Configuration options:
            - url
            - org
            - token
            - timeout,
            - verify_ssl
            - ssl_ca_cert
            - cert_file
            - cert_key_file
            - cert_key_password
            - connection_pool_maxsize
            - auth_basic
            - profilers
            - proxy


        config.ini example::

            [influx2]
            url=http://localhost:8086
            org=my-org
            token=my-token
            timeout=6000
            connection_pool_maxsize=25
            auth_basic=false
            profilers=query,operator
            proxy=http:proxy.domain.org:8080

            [tags]
            id = 132-987-655
            customer = California Miner
            data_center = ${env.data_center}

        config.toml example::

            [influx2]
                url = "http://localhost:8086"
                token = "my-token"
                org = "my-org"
                timeout = 6000
                connection_pool_maxsize = 25
                auth_basic = false
                profilers="query, operator"
                proxy = "http://proxy.domain.org:8080"

            [tags]
                id = "132-987-655"
                customer = "California Miner"
                data_center = "${env.data_center}"

        config.json example::

            {
                "url": "http://localhost:8086",
                "token": "my-token",
                "org": "my-org",
                "active": true,
                "timeout": 6000,
                "connection_pool_maxsize": 55,
                "auth_basic": false,
                "profilers": "query, operator",
                "tags": {
                    "id": "132-987-655",
                    "customer": "California Miner",
                    "data_center": "${env.data_center}"
                }
            }

        """
        return InfluxDBClient._from_config_file(config_file=config_file, debug=debug, enable_gzip=enable_gzip, **kwargs)

    @classmethod
    def from_env_properties(cls, debug=None, enable_gzip=False, **kwargs):
        """
        Configure client via environment properties.

        :param debug: Enable verbose logging of http requests
        :param enable_gzip: Enable Gzip compression for http requests. Currently, only the "Write" and "Query" endpoints
                            supports the Gzip compression.
        :key str proxy: Set this to configure the http proxy to be used (ex. http://localhost:3128)
        :key str proxy_headers: A dictionary containing headers that will be sent to the proxy. Could be used for proxy
                                authentication.
        :key urllib3.util.retry.Retry retries: Set the default retry strategy that is used for all HTTP requests
                                               except batching writes. As a default there is no one retry strategy.
        :key ssl.SSLContext ssl_context: Specify a custom Python SSL Context for the TLS/ mTLS handshake.
                                         Be aware that only delivered certificate/ key files or an SSL Context are
                                         possible.

        Supported environment properties:
            - INFLUXDB_V2_URL
            - INFLUXDB_V2_ORG
            - INFLUXDB_V2_TOKEN
            - INFLUXDB_V2_TIMEOUT
            - INFLUXDB_V2_VERIFY_SSL
            - INFLUXDB_V2_SSL_CA_CERT
            - INFLUXDB_V2_CERT_FILE
            - INFLUXDB_V2_CERT_KEY_FILE
            - INFLUXDB_V2_CERT_KEY_PASSWORD
            - INFLUXDB_V2_CONNECTION_POOL_MAXSIZE
            - INFLUXDB_V2_AUTH_BASIC
            - INFLUXDB_V2_PROFILERS
            - INFLUXDB_V2_TAG
        """
        return InfluxDBClient._from_env_properties(debug=debug, enable_gzip=enable_gzip, **kwargs)

    def write_api(self, write_options=WriteOptions(), point_settings=PointSettings(), **kwargs) -> WriteApi:
        """
        Create Write API instance.

        Example:
            .. code-block:: python

                from influxdb_client import InfluxDBClient
                from influxdb_client.client.write_api import SYNCHRONOUS


                # Initialize SYNCHRONOUS instance of WriteApi
                with InfluxDBClient(url="http://localhost:8086", token="my-token", org="my-org") as client:
                    write_api = client.write_api(write_options=SYNCHRONOUS)

        If you would like to use a **background batching**, you have to configure client like this:

        .. code-block:: python

            from influxdb_client import InfluxDBClient

            # Initialize background batching instance of WriteApi
            with InfluxDBClient(url="http://localhost:8086", token="my-token", org="my-org") as client:
                with client.write_api() as write_api:
                    pass

        There is also possibility to use callbacks to notify about state of background batches:

        .. code-block:: python

            from influxdb_client import InfluxDBClient
            from influxdb_client.client.exceptions import InfluxDBError


            class BatchingCallback(object):

                def success(self, conf: (str, str, str), data: str):
                    print(f"Written batch: {conf}, data: {data}")

                def error(self, conf: (str, str, str), data: str, exception: InfluxDBError):
                    print(f"Cannot write batch: {conf}, data: {data} due: {exception}")

                def retry(self, conf: (str, str, str), data: str, exception: InfluxDBError):
                    print(f"Retryable error occurs for batch: {conf}, data: {data} retry: {exception}")


            with InfluxDBClient(url="http://localhost:8086", token="my-token", org="my-org") as client:
                callback = BatchingCallback()
                with client.write_api(success_callback=callback.success,
                                      error_callback=callback.error,
                                      retry_callback=callback.retry) as write_api:
                    pass

        :param write_options: Write API configuration
        :param point_settings: settings to store default tags
        :key success_callback: The callable ``callback`` to run after having successfully written a batch.

                               The callable must accept two arguments:
                                    - `Tuple`: ``(bucket, organization, precision)``
                                    - `str`: written data

                               **[batching mode]**

        :key error_callback: The callable ``callback`` to run after having unsuccessfully written a batch.

                             The callable must accept three arguments:
                                - `Tuple`: ``(bucket, organization, precision)``
                                - `str`: written data
                                - `Exception`: an occurred error

                             **[batching mode]**
        :key retry_callback: The callable ``callback`` to run after retryable error occurred.

                             The callable must accept three arguments:
                                - `Tuple`: ``(bucket, organization, precision)``
                                - `str`: written data
                                - `Exception`: an retryable error

                             **[batching mode]**
        :return: write api instance
        """
        return WriteApi(influxdb_client=self, write_options=write_options, point_settings=point_settings, **kwargs)

    def query_api(self, query_options: QueryOptions = QueryOptions()) -> QueryApi:
        """
        Create an Query API instance.

        :param query_options: optional query api configuration
        :return: Query api instance
        """
        return QueryApi(self, query_options)

    def invokable_scripts_api(self) -> InvokableScriptsApi:
        """
        Create an InvokableScripts API instance.

        :return: InvokableScripts API instance
        """
        return InvokableScriptsApi(self)

    def close(self):
        """Shutdown the client."""
        self.__del__()

    def __del__(self):
        """Shutdown the client."""
        if self.api_client:
            self.api_client.__del__()
            self.api_client = None

    def buckets_api(self) -> BucketsApi:
        """
        Create the Bucket API instance.

        :return: buckets api
        """
        return BucketsApi(self)

    def authorizations_api(self) -> AuthorizationsApi:
        """
        Create the Authorizations API instance.

        :return: authorizations api
        """
        return AuthorizationsApi(self)

    def users_api(self) -> UsersApi:
        """
        Create the Users API instance.

        :return: users api
        """
        return UsersApi(self)

    def organizations_api(self) -> OrganizationsApi:
        """
        Create the Organizations API instance.

        :return: organizations api
        """
        return OrganizationsApi(self)

    def tasks_api(self) -> TasksApi:
        """
        Create the Tasks API instance.

        :return: tasks api
        """
        return TasksApi(self)

    def labels_api(self) -> LabelsApi:
        """
        Create the Labels API instance.

        :return: labels api
        """
        return LabelsApi(self)

    def health(self) -> HealthCheck:
        """
        Get the health of an instance.

        :return: HealthCheck
        """
        warnings.warn("This method is deprecated. Call 'ping()' instead.", DeprecationWarning)
        health_service = HealthService(self.api_client)

        try:
            health = health_service.get_health()
            return health
        except Exception as e:
            return HealthCheck(name="influxdb", message=str(e), status="fail")

    def ping(self) -> bool:
        """
        Return the status of InfluxDB instance.

        :return: The status of InfluxDB.
        """
        ping_service = PingService(self.api_client)

        try:
            ping_service.get_ping()
            return True
        except Exception as ex:
            logger.debug("Unexpected error during /ping: %s", ex)
            return False

    def version(self) -> str:
        """
        Return the version of the connected InfluxDB Server.

        :return: The version of InfluxDB.
        """
        ping_service = PingService(self.api_client)

        response = ping_service.get_ping_with_http_info(_return_http_data_only=False)

        return ping_service.response_header(response)

    def build(self) -> str:
        """
        Return the build type of the connected InfluxDB Server.

        :return: The type of InfluxDB build.
        """
        ping_service = PingService(self.api_client)

        return ping_service.build_type()

    def ready(self) -> Ready:
        """
        Get The readiness of the InfluxDB 2.0.

        :return: Ready
        """
        ready_service = ReadyService(self.api_client)
        return ready_service.get_ready()

    def delete_api(self) -> DeleteApi:
        """
        Get the delete metrics API instance.

        :return: delete api
        """
        return DeleteApi(self)



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class Source(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'links': 'SourceLinks',
        'id': 'str',
        'org_id': 'str',
        'default': 'bool',
        'name': 'str',
        'type': 'str',
        'url': 'str',
        'insecure_skip_verify': 'bool',
        'telegraf': 'str',
        'token': 'str',
        'username': 'str',
        'password': 'str',
        'shared_secret': 'str',
        'meta_url': 'str',
        'default_rp': 'str',
        'languages': 'list[str]'
    }

    attribute_map = {
        'links': 'links',
        'id': 'id',
        'org_id': 'orgID',
        'default': 'default',
        'name': 'name',
        'type': 'type',
        'url': 'url',
        'insecure_skip_verify': 'insecureSkipVerify',
        'telegraf': 'telegraf',
        'token': 'token',
        'username': 'username',
        'password': 'password',
        'shared_secret': 'sharedSecret',
        'meta_url': 'metaUrl',
        'default_rp': 'defaultRP',
        'languages': 'languages'
    }

    def __init__(self, links=None, id=None, org_id=None, default=None, name=None, type=None, url=None, insecure_skip_verify=None, telegraf=None, token=None, username=None, password=None, shared_secret=None, meta_url=None, default_rp=None, languages=None):  # noqa: E501,D401,D403
        """Source - a model defined in OpenAPI."""  # noqa: E501
        self._links = None
        self._id = None
        self._org_id = None
        self._default = None
        self._name = None
        self._type = None
        self._url = None
        self._insecure_skip_verify = None
        self._telegraf = None
        self._token = None
        self._username = None
        self._password = None
        self._shared_secret = None
        self._meta_url = None
        self._default_rp = None
        self._languages = None
        self.discriminator = None

        if links is not None:
            self.links = links
        if id is not None:
            self.id = id
        if org_id is not None:
            self.org_id = org_id
        if default is not None:
            self.default = default
        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if url is not None:
            self.url = url
        if insecure_skip_verify is not None:
            self.insecure_skip_verify = insecure_skip_verify
        if telegraf is not None:
            self.telegraf = telegraf
        if token is not None:
            self.token = token
        if username is not None:
            self.username = username
        if password is not None:
            self.password = password
        if shared_secret is not None:
            self.shared_secret = shared_secret
        if meta_url is not None:
            self.meta_url = meta_url
        if default_rp is not None:
            self.default_rp = default_rp
        if languages is not None:
            self.languages = languages

    @property
    def links(self):
        """Get the links of this Source.

        :return: The links of this Source.
        :rtype: SourceLinks
        """  # noqa: E501
        return self._links

    @links.setter
    def links(self, links):
        """Set the links of this Source.

        :param links: The links of this Source.
        :type: SourceLinks
        """  # noqa: E501
        self._links = links

    @property
    def id(self):
        """Get the id of this Source.

        :return: The id of this Source.
        :rtype: str
        """  # noqa: E501
        return self._id

    @id.setter
    def id(self, id):
        """Set the id of this Source.

        :param id: The id of this Source.
        :type: str
        """  # noqa: E501
        self._id = id

    @property
    def org_id(self):
        """Get the org_id of this Source.

        :return: The org_id of this Source.
        :rtype: str
        """  # noqa: E501
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Set the org_id of this Source.

        :param org_id: The org_id of this Source.
        :type: str
        """  # noqa: E501
        self._org_id = org_id

    @property
    def default(self):
        """Get the default of this Source.

        :return: The default of this Source.
        :rtype: bool
        """  # noqa: E501
        return self._default

    @default.setter
    def default(self, default):
        """Set the default of this Source.

        :param default: The default of this Source.
        :type: bool
        """  # noqa: E501
        self._default = default

    @property
    def name(self):
        """Get the name of this Source.

        :return: The name of this Source.
        :rtype: str
        """  # noqa: E501
        return self._name

    @name.setter
    def name(self, name):
        """Set the name of this Source.

        :param name: The name of this Source.
        :type: str
        """  # noqa: E501
        self._name = name

    @property
    def type(self):
        """Get the type of this Source.

        :return: The type of this Source.
        :rtype: str
        """  # noqa: E501
        return self._type

    @type.setter
    def type(self, type):
        """Set the type of this Source.

        :param type: The type of this Source.
        :type: str
        """  # noqa: E501
        self._type = type

    @property
    def url(self):
        """Get the url of this Source.

        :return: The url of this Source.
        :rtype: str
        """  # noqa: E501
        return self._url

    @url.setter
    def url(self, url):
        """Set the url of this Source.

        :param url: The url of this Source.
        :type: str
        """  # noqa: E501
        self._url = url

    @property
    def insecure_skip_verify(self):
        """Get the insecure_skip_verify of this Source.

        :return: The insecure_skip_verify of this Source.
        :rtype: bool
        """  # noqa: E501
        return self._insecure_skip_verify

    @insecure_skip_verify.setter
    def insecure_skip_verify(self, insecure_skip_verify):
        """Set the insecure_skip_verify of this Source.

        :param insecure_skip_verify: The insecure_skip_verify of this Source.
        :type: bool
        """  # noqa: E501
        self._insecure_skip_verify = insecure_skip_verify

    @property
    def telegraf(self):
        """Get the telegraf of this Source.

        :return: The telegraf of this Source.
        :rtype: str
        """  # noqa: E501
        return self._telegraf

    @telegraf.setter
    def telegraf(self, telegraf):
        """Set the telegraf of this Source.

        :param telegraf: The telegraf of this Source.
        :type: str
        """  # noqa: E501
        self._telegraf = telegraf

    @property
    def token(self):
        """Get the token of this Source.

        :return: The token of this Source.
        :rtype: str
        """  # noqa: E501
        return self._token

    @token.setter
    def token(self, token):
        """Set the token of this Source.

        :param token: The token of this Source.
        :type: str
        """  # noqa: E501
        self._token = token

    @property
    def username(self):
        """Get the username of this Source.

        :return: The username of this Source.
        :rtype: str
        """  # noqa: E501
        return self._username

    @username.setter
    def username(self, username):
        """Set the username of this Source.

        :param username: The username of this Source.
        :type: str
        """  # noqa: E501
        self._username = username

    @property
    def password(self):
        """Get the password of this Source.

        :return: The password of this Source.
        :rtype: str
        """  # noqa: E501
        return self._password

    @password.setter
    def password(self, password):
        """Set the password of this Source.

        :param password: The password of this Source.
        :type: str
        """  # noqa: E501
        self._password = password

    @property
    def shared_secret(self):
        """Get the shared_secret of this Source.

        :return: The shared_secret of this Source.
        :rtype: str
        """  # noqa: E501
        return self._shared_secret

    @shared_secret.setter
    def shared_secret(self, shared_secret):
        """Set the shared_secret of this Source.

        :param shared_secret: The shared_secret of this Source.
        :type: str
        """  # noqa: E501
        self._shared_secret = shared_secret

    @property
    def meta_url(self):
        """Get the meta_url of this Source.

        :return: The meta_url of this Source.
        :rtype: str
        """  # noqa: E501
        return self._meta_url

    @meta_url.setter
    def meta_url(self, meta_url):
        """Set the meta_url of this Source.

        :param meta_url: The meta_url of this Source.
        :type: str
        """  # noqa: E501
        self._meta_url = meta_url

    @property
    def default_rp(self):
        """Get the default_rp of this Source.

        :return: The default_rp of this Source.
        :rtype: str
        """  # noqa: E501
        return self._default_rp

    @default_rp.setter
    def default_rp(self, default_rp):
        """Set the default_rp of this Source.

        :param default_rp: The default_rp of this Source.
        :type: str
        """  # noqa: E501
        self._default_rp = default_rp

    @property
    def languages(self):
        """Get the languages of this Source.

        :return: The languages of this Source.
        :rtype: list[str]
        """  # noqa: E501
        return self._languages

    @languages.setter
    def languages(self, languages):
        """Set the languages of this Source.

        :param languages: The languages of this Source.
        :type: list[str]
        """  # noqa: E501
        allowed_values = ["flux", "influxql"]  # noqa: E501
        if not set(languages).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `languages` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(languages) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )
        self._languages = languages

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, Source):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

from influxdb_client.domain.notification_endpoint_discriminator import NotificationEndpointDiscriminator


class PagerDutyNotificationEndpoint(NotificationEndpointDiscriminator):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'client_url': 'str',
        'routing_key': 'str',
        'id': 'str',
        'org_id': 'str',
        'user_id': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'description': 'str',
        'name': 'str',
        'status': 'str',
        'labels': 'list[Label]',
        'links': 'NotificationEndpointBaseLinks',
        'type': 'NotificationEndpointType'
    }

    attribute_map = {
        'client_url': 'clientURL',
        'routing_key': 'routingKey',
        'id': 'id',
        'org_id': 'orgID',
        'user_id': 'userID',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'description': 'description',
        'name': 'name',
        'status': 'status',
        'labels': 'labels',
        'links': 'links',
        'type': 'type'
    }

    def __init__(self, client_url=None, routing_key=None, id=None, org_id=None, user_id=None, created_at=None, updated_at=None, description=None, name=None, status='active', labels=None, links=None, type="pagerduty"):  # noqa: E501,D401,D403
        """PagerDutyNotificationEndpoint - a model defined in OpenAPI."""  # noqa: E501
        NotificationEndpointDiscriminator.__init__(self, id=id, org_id=org_id, user_id=user_id, created_at=created_at, updated_at=updated_at, description=description, name=name, status=status, labels=labels, links=links, type=type)  # noqa: E501

        self._client_url = None
        self._routing_key = None
        self.discriminator = None

        if client_url is not None:
            self.client_url = client_url
        self.routing_key = routing_key

    @property
    def client_url(self):
        """Get the client_url of this PagerDutyNotificationEndpoint.

        :return: The client_url of this PagerDutyNotificationEndpoint.
        :rtype: str
        """  # noqa: E501
        return self._client_url

    @client_url.setter
    def client_url(self, client_url):
        """Set the client_url of this PagerDutyNotificationEndpoint.

        :param client_url: The client_url of this PagerDutyNotificationEndpoint.
        :type: str
        """  # noqa: E501
        self._client_url = client_url

    @property
    def routing_key(self):
        """Get the routing_key of this PagerDutyNotificationEndpoint.

        :return: The routing_key of this PagerDutyNotificationEndpoint.
        :rtype: str
        """  # noqa: E501
        return self._routing_key

    @routing_key.setter
    def routing_key(self, routing_key):
        """Set the routing_key of this PagerDutyNotificationEndpoint.

        :param routing_key: The routing_key of this PagerDutyNotificationEndpoint.
        :type: str
        """  # noqa: E501
        if routing_key is None:
            raise ValueError("Invalid value for `routing_key`, must not be `None`")  # noqa: E501
        self._routing_key = routing_key

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, PagerDutyNotificationEndpoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from influxdb_client.service._base_service import _BaseService


class LegacyAuthorizationsService(_BaseService):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):  # noqa: E501,D401,D403
        """LegacyAuthorizationsService - a operation defined in OpenAPI."""
        super().__init__(api_client)

    def delete_legacy_authorizations_id(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        """Delete a legacy authorization.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_legacy_authorizations_id(auth_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: The ID of the legacy authorization to delete. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_legacy_authorizations_id_with_http_info(auth_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_legacy_authorizations_id_with_http_info(auth_id, **kwargs)  # noqa: E501
            return data

    def delete_legacy_authorizations_id_with_http_info(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        """Delete a legacy authorization.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_legacy_authorizations_id_with_http_info(auth_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: The ID of the legacy authorization to delete. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._delete_legacy_authorizations_id_prepare(auth_id, **kwargs)

        return self.api_client.call_api(
            '/private/legacy/authorizations/{authID}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def delete_legacy_authorizations_id_async(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        """Delete a legacy authorization.

        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str auth_id: The ID of the legacy authorization to delete. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._delete_legacy_authorizations_id_prepare(auth_id, **kwargs)

        return await self.api_client.call_api(
            '/private/legacy/authorizations/{authID}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _delete_legacy_authorizations_id_prepare(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['auth_id', 'zap_trace_span']  # noqa: E501
        self._check_operation_params('delete_legacy_authorizations_id', all_params, local_var_params)
        # verify the required parameter 'auth_id' is set
        if ('auth_id' not in local_var_params or
                local_var_params['auth_id'] is None):
            raise ValueError("Missing the required parameter `auth_id` when calling `delete_legacy_authorizations_id`")  # noqa: E501

        path_params = {}
        if 'auth_id' in local_var_params:
            path_params['authID'] = local_var_params['auth_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def get_legacy_authorizations(self, **kwargs):  # noqa: E501,D401,D403
        """List all legacy authorizations.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_legacy_authorizations(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :param str user_id: Only show legacy authorizations that belong to a user ID.
        :param str user: Only show legacy authorizations that belong to a user name.
        :param str org_id: Only show legacy authorizations that belong to an organization ID.
        :param str org: Only show legacy authorizations that belong to a organization name.
        :param str token: Only show legacy authorizations with a specified token (auth name).
        :param str auth_id: Only show legacy authorizations with a specified auth ID.
        :return: Authorizations
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_legacy_authorizations_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_legacy_authorizations_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_legacy_authorizations_with_http_info(self, **kwargs):  # noqa: E501,D401,D403
        """List all legacy authorizations.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_legacy_authorizations_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :param str user_id: Only show legacy authorizations that belong to a user ID.
        :param str user: Only show legacy authorizations that belong to a user name.
        :param str org_id: Only show legacy authorizations that belong to an organization ID.
        :param str org: Only show legacy authorizations that belong to a organization name.
        :param str token: Only show legacy authorizations with a specified token (auth name).
        :param str auth_id: Only show legacy authorizations with a specified auth ID.
        :return: Authorizations
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_legacy_authorizations_prepare(**kwargs)

        return self.api_client.call_api(
            '/private/legacy/authorizations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorizations',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_legacy_authorizations_async(self, **kwargs):  # noqa: E501,D401,D403
        """List all legacy authorizations.

        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :param str user_id: Only show legacy authorizations that belong to a user ID.
        :param str user: Only show legacy authorizations that belong to a user name.
        :param str org_id: Only show legacy authorizations that belong to an organization ID.
        :param str org: Only show legacy authorizations that belong to a organization name.
        :param str token: Only show legacy authorizations with a specified token (auth name).
        :param str auth_id: Only show legacy authorizations with a specified auth ID.
        :return: Authorizations
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_legacy_authorizations_prepare(**kwargs)

        return await self.api_client.call_api(
            '/private/legacy/authorizations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorizations',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_legacy_authorizations_prepare(self, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['zap_trace_span', 'user_id', 'user', 'org_id', 'org', 'token', 'auth_id']  # noqa: E501
        self._check_operation_params('get_legacy_authorizations', all_params, local_var_params)

        path_params = {}

        query_params = []
        if 'user_id' in local_var_params:
            query_params.append(('userID', local_var_params['user_id']))  # noqa: E501
        if 'user' in local_var_params:
            query_params.append(('user', local_var_params['user']))  # noqa: E501
        if 'org_id' in local_var_params:
            query_params.append(('orgID', local_var_params['org_id']))  # noqa: E501
        if 'org' in local_var_params:
            query_params.append(('org', local_var_params['org']))  # noqa: E501
        if 'token' in local_var_params:
            query_params.append(('token', local_var_params['token']))  # noqa: E501
        if 'auth_id' in local_var_params:
            query_params.append(('authID', local_var_params['auth_id']))  # noqa: E501

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def get_legacy_authorizations_id(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        """Retrieve a legacy authorization.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_legacy_authorizations_id(auth_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: The ID of the legacy authorization to get. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_legacy_authorizations_id_with_http_info(auth_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_legacy_authorizations_id_with_http_info(auth_id, **kwargs)  # noqa: E501
            return data

    def get_legacy_authorizations_id_with_http_info(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        """Retrieve a legacy authorization.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_legacy_authorizations_id_with_http_info(auth_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: The ID of the legacy authorization to get. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_legacy_authorizations_id_prepare(auth_id, **kwargs)

        return self.api_client.call_api(
            '/private/legacy/authorizations/{authID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorization',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_legacy_authorizations_id_async(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        """Retrieve a legacy authorization.

        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str auth_id: The ID of the legacy authorization to get. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_legacy_authorizations_id_prepare(auth_id, **kwargs)

        return await self.api_client.call_api(
            '/private/legacy/authorizations/{authID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorization',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_legacy_authorizations_id_prepare(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['auth_id', 'zap_trace_span']  # noqa: E501
        self._check_operation_params('get_legacy_authorizations_id', all_params, local_var_params)
        # verify the required parameter 'auth_id' is set
        if ('auth_id' not in local_var_params or
                local_var_params['auth_id'] is None):
            raise ValueError("Missing the required parameter `auth_id` when calling `get_legacy_authorizations_id`")  # noqa: E501

        path_params = {}
        if 'auth_id' in local_var_params:
            path_params['authID'] = local_var_params['auth_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def patch_legacy_authorizations_id(self, auth_id, authorization_update_request, **kwargs):  # noqa: E501,D401,D403
        """Update a legacy authorization to be active or inactive.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_legacy_authorizations_id(auth_id, authorization_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: The ID of the legacy authorization to update. (required)
        :param AuthorizationUpdateRequest authorization_update_request: Legacy authorization to update (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.patch_legacy_authorizations_id_with_http_info(auth_id, authorization_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.patch_legacy_authorizations_id_with_http_info(auth_id, authorization_update_request, **kwargs)  # noqa: E501
            return data

    def patch_legacy_authorizations_id_with_http_info(self, auth_id, authorization_update_request, **kwargs):  # noqa: E501,D401,D403
        """Update a legacy authorization to be active or inactive.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_legacy_authorizations_id_with_http_info(auth_id, authorization_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: The ID of the legacy authorization to update. (required)
        :param AuthorizationUpdateRequest authorization_update_request: Legacy authorization to update (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._patch_legacy_authorizations_id_prepare(auth_id, authorization_update_request, **kwargs)

        return self.api_client.call_api(
            '/private/legacy/authorizations/{authID}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorization',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def patch_legacy_authorizations_id_async(self, auth_id, authorization_update_request, **kwargs):  # noqa: E501,D401,D403
        """Update a legacy authorization to be active or inactive.

        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str auth_id: The ID of the legacy authorization to update. (required)
        :param AuthorizationUpdateRequest authorization_update_request: Legacy authorization to update (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._patch_legacy_authorizations_id_prepare(auth_id, authorization_update_request, **kwargs)

        return await self.api_client.call_api(
            '/private/legacy/authorizations/{authID}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorization',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _patch_legacy_authorizations_id_prepare(self, auth_id, authorization_update_request, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['auth_id', 'authorization_update_request', 'zap_trace_span']  # noqa: E501
        self._check_operation_params('patch_legacy_authorizations_id', all_params, local_var_params)
        # verify the required parameter 'auth_id' is set
        if ('auth_id' not in local_var_params or
                local_var_params['auth_id'] is None):
            raise ValueError("Missing the required parameter `auth_id` when calling `patch_legacy_authorizations_id`")  # noqa: E501
        # verify the required parameter 'authorization_update_request' is set
        if ('authorization_update_request' not in local_var_params or
                local_var_params['authorization_update_request'] is None):
            raise ValueError("Missing the required parameter `authorization_update_request` when calling `patch_legacy_authorizations_id`")  # noqa: E501

        path_params = {}
        if 'auth_id' in local_var_params:
            path_params['authID'] = local_var_params['auth_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        body_params = None
        if 'authorization_update_request' in local_var_params:
            body_params = local_var_params['authorization_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def post_legacy_authorizations(self, legacy_authorization_post_request, **kwargs):  # noqa: E501,D401,D403
        """Create a legacy authorization.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_legacy_authorizations(legacy_authorization_post_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LegacyAuthorizationPostRequest legacy_authorization_post_request: Legacy authorization to create (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_legacy_authorizations_with_http_info(legacy_authorization_post_request, **kwargs)  # noqa: E501
        else:
            (data) = self.post_legacy_authorizations_with_http_info(legacy_authorization_post_request, **kwargs)  # noqa: E501
            return data

    def post_legacy_authorizations_with_http_info(self, legacy_authorization_post_request, **kwargs):  # noqa: E501,D401,D403
        """Create a legacy authorization.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_legacy_authorizations_with_http_info(legacy_authorization_post_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LegacyAuthorizationPostRequest legacy_authorization_post_request: Legacy authorization to create (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._post_legacy_authorizations_prepare(legacy_authorization_post_request, **kwargs)

        return self.api_client.call_api(
            '/private/legacy/authorizations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorization',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def post_legacy_authorizations_async(self, legacy_authorization_post_request, **kwargs):  # noqa: E501,D401,D403
        """Create a legacy authorization.

        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param LegacyAuthorizationPostRequest legacy_authorization_post_request: Legacy authorization to create (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._post_legacy_authorizations_prepare(legacy_authorization_post_request, **kwargs)

        return await self.api_client.call_api(
            '/private/legacy/authorizations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorization',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _post_legacy_authorizations_prepare(self, legacy_authorization_post_request, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['legacy_authorization_post_request', 'zap_trace_span']  # noqa: E501
        self._check_operation_params('post_legacy_authorizations', all_params, local_var_params)
        # verify the required parameter 'legacy_authorization_post_request' is set
        if ('legacy_authorization_post_request' not in local_var_params or
                local_var_params['legacy_authorization_post_request'] is None):
            raise ValueError("Missing the required parameter `legacy_authorization_post_request` when calling `post_legacy_authorizations`")  # noqa: E501

        path_params = {}

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        body_params = None
        if 'legacy_authorization_post_request' in local_var_params:
            body_params = local_var_params['legacy_authorization_post_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def post_legacy_authorizations_id_password(self, auth_id, password_reset_body, **kwargs):  # noqa: E501,D401,D403
        """Set a legacy authorization password.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_legacy_authorizations_id_password(auth_id, password_reset_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: The ID of the legacy authorization to update. (required)
        :param PasswordResetBody password_reset_body: New password (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_legacy_authorizations_id_password_with_http_info(auth_id, password_reset_body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_legacy_authorizations_id_password_with_http_info(auth_id, password_reset_body, **kwargs)  # noqa: E501
            return data

    def post_legacy_authorizations_id_password_with_http_info(self, auth_id, password_reset_body, **kwargs):  # noqa: E501,D401,D403
        """Set a legacy authorization password.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_legacy_authorizations_id_password_with_http_info(auth_id, password_reset_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: The ID of the legacy authorization to update. (required)
        :param PasswordResetBody password_reset_body: New password (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._post_legacy_authorizations_id_password_prepare(auth_id, password_reset_body, **kwargs)

        return self.api_client.call_api(
            '/private/legacy/authorizations/{authID}/password', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def post_legacy_authorizations_id_password_async(self, auth_id, password_reset_body, **kwargs):  # noqa: E501,D401,D403
        """Set a legacy authorization password.

        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str auth_id: The ID of the legacy authorization to update. (required)
        :param PasswordResetBody password_reset_body: New password (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._post_legacy_authorizations_id_password_prepare(auth_id, password_reset_body, **kwargs)

        return await self.api_client.call_api(
            '/private/legacy/authorizations/{authID}/password', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _post_legacy_authorizations_id_password_prepare(self, auth_id, password_reset_body, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['auth_id', 'password_reset_body', 'zap_trace_span']  # noqa: E501
        self._check_operation_params('post_legacy_authorizations_id_password', all_params, local_var_params)
        # verify the required parameter 'auth_id' is set
        if ('auth_id' not in local_var_params or
                local_var_params['auth_id'] is None):
            raise ValueError("Missing the required parameter `auth_id` when calling `post_legacy_authorizations_id_password`")  # noqa: E501
        # verify the required parameter 'password_reset_body' is set
        if ('password_reset_body' not in local_var_params or
                local_var_params['password_reset_body'] is None):
            raise ValueError("Missing the required parameter `password_reset_body` when calling `post_legacy_authorizations_id_password`")  # noqa: E501

        path_params = {}
        if 'auth_id' in local_var_params:
            path_params['authID'] = local_var_params['auth_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        body_params = None
        if 'password_reset_body' in local_var_params:
            body_params = local_var_params['password_reset_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params



"""Delete time series data from InfluxDB."""

from datetime import datetime
from typing import Union

from influxdb_client import Organization
from influxdb_client.client._base import _BaseDeleteApi
from influxdb_client.client.util.helpers import get_org_query_param


class DeleteApiAsync(_BaseDeleteApi):
    """Async implementation for '/api/v2/delete' endpoint."""

    def __init__(self, influxdb_client):
        """Initialize defaults."""
        super().__init__(influxdb_client)

    async def delete(self, start: Union[str, datetime], stop: Union[str, datetime], predicate: str, bucket: str,
                     org: Union[str, Organization, None] = None) -> bool:
        """
        Delete Time series data from InfluxDB.

        :param str, datetime.datetime start: start time
        :param str, datetime.datetime stop: stop time
        :param str predicate: predicate
        :param str bucket: bucket id or name from which data will be deleted
        :param str, Organization org: specifies the organization to delete data from.
                                      Take the ``ID``, ``Name`` or ``Organization``.
                                      If not specified the default value from ``InfluxDBClientAsync.org`` is used.
        :return: ``True`` for successfully deleted data, otherwise raise an exception
        """
        predicate_request = self._prepare_predicate_request(start, stop, predicate)
        org_param = get_org_query_param(org=org, client=self._influxdb_client, required_id=False)

        response = await self._service.post_delete_async(delete_predicate_request=predicate_request, bucket=bucket,
                                                         org=org_param, _return_http_data_only=False)
        return response[1] == 204



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from influxdb_client.service._base_service import _BaseService


class BackupService(_BaseService):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):  # noqa: E501,D401,D403
        """BackupService - a operation defined in OpenAPI."""
        super().__init__(api_client)

    def get_backup_kv(self, **kwargs):  # noqa: E501,D401,D403
        """Download snapshot of metadata stored in the server's embedded KV store. Don't use with InfluxDB versions greater than InfluxDB 2.1.x..

        Retrieves a snapshot of metadata stored in the server's embedded KV store. InfluxDB versions greater than 2.1.x don't include metadata stored in embedded SQL; avoid using this endpoint with versions greater than 2.1.x.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_backup_kv(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_backup_kv_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_backup_kv_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_backup_kv_with_http_info(self, **kwargs):  # noqa: E501,D401,D403
        """Download snapshot of metadata stored in the server's embedded KV store. Don't use with InfluxDB versions greater than InfluxDB 2.1.x..

        Retrieves a snapshot of metadata stored in the server's embedded KV store. InfluxDB versions greater than 2.1.x don't include metadata stored in embedded SQL; avoid using this endpoint with versions greater than 2.1.x.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_backup_kv_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_backup_kv_prepare(**kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/backup/kv', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='file',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_backup_kv_async(self, **kwargs):  # noqa: E501,D401,D403
        """Download snapshot of metadata stored in the server's embedded KV store. Don't use with InfluxDB versions greater than InfluxDB 2.1.x..

        Retrieves a snapshot of metadata stored in the server's embedded KV store. InfluxDB versions greater than 2.1.x don't include metadata stored in embedded SQL; avoid using this endpoint with versions greater than 2.1.x.
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_backup_kv_prepare(**kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/backup/kv', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='file',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_backup_kv_prepare(self, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['zap_trace_span']  # noqa: E501
        self._check_operation_params('get_backup_kv', all_params, local_var_params)

        path_params = {}

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream', 'application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def get_backup_metadata(self, **kwargs):  # noqa: E501,D401,D403
        """Download snapshot of all metadata in the server.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_backup_metadata(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :param str accept_encoding: Indicates the content encoding (usually a compression algorithm) that the client can understand.
        :return: MetadataBackup
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_backup_metadata_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_backup_metadata_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_backup_metadata_with_http_info(self, **kwargs):  # noqa: E501,D401,D403
        """Download snapshot of all metadata in the server.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_backup_metadata_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :param str accept_encoding: Indicates the content encoding (usually a compression algorithm) that the client can understand.
        :return: MetadataBackup
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_backup_metadata_prepare(**kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/backup/metadata', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='MetadataBackup',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_backup_metadata_async(self, **kwargs):  # noqa: E501,D401,D403
        """Download snapshot of all metadata in the server.

        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :param str accept_encoding: Indicates the content encoding (usually a compression algorithm) that the client can understand.
        :return: MetadataBackup
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_backup_metadata_prepare(**kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/backup/metadata', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='MetadataBackup',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_backup_metadata_prepare(self, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['zap_trace_span', 'accept_encoding']  # noqa: E501
        self._check_operation_params('get_backup_metadata', all_params, local_var_params)

        path_params = {}

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501
        if 'accept_encoding' in local_var_params:
            header_params['Accept-Encoding'] = local_var_params['accept_encoding']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['multipart/mixed', 'application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def get_backup_shard_id(self, shard_id, **kwargs):  # noqa: E501,D401,D403
        """Download snapshot of all TSM data in a shard.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_backup_shard_id(shard_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int shard_id: The shard ID. (required)
        :param str zap_trace_span: OpenTracing span context
        :param str accept_encoding: Indicates the content encoding (usually a compression algorithm) that the client can understand.
        :param datetime since: The earliest time [RFC3339 date/time format](https://docs.influxdata.com/influxdb/latest/reference/glossary/#rfc3339-timestamp) to include in the snapshot.
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_backup_shard_id_with_http_info(shard_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_backup_shard_id_with_http_info(shard_id, **kwargs)  # noqa: E501
            return data

    def get_backup_shard_id_with_http_info(self, shard_id, **kwargs):  # noqa: E501,D401,D403
        """Download snapshot of all TSM data in a shard.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_backup_shard_id_with_http_info(shard_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int shard_id: The shard ID. (required)
        :param str zap_trace_span: OpenTracing span context
        :param str accept_encoding: Indicates the content encoding (usually a compression algorithm) that the client can understand.
        :param datetime since: The earliest time [RFC3339 date/time format](https://docs.influxdata.com/influxdb/latest/reference/glossary/#rfc3339-timestamp) to include in the snapshot.
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_backup_shard_id_prepare(shard_id, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/backup/shards/{shardID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='file',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_backup_shard_id_async(self, shard_id, **kwargs):  # noqa: E501,D401,D403
        """Download snapshot of all TSM data in a shard.

        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param int shard_id: The shard ID. (required)
        :param str zap_trace_span: OpenTracing span context
        :param str accept_encoding: Indicates the content encoding (usually a compression algorithm) that the client can understand.
        :param datetime since: The earliest time [RFC3339 date/time format](https://docs.influxdata.com/influxdb/latest/reference/glossary/#rfc3339-timestamp) to include in the snapshot.
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_backup_shard_id_prepare(shard_id, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/backup/shards/{shardID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='file',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_backup_shard_id_prepare(self, shard_id, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['shard_id', 'zap_trace_span', 'accept_encoding', 'since']  # noqa: E501
        self._check_operation_params('get_backup_shard_id', all_params, local_var_params)
        # verify the required parameter 'shard_id' is set
        if ('shard_id' not in local_var_params or
                local_var_params['shard_id'] is None):
            raise ValueError("Missing the required parameter `shard_id` when calling `get_backup_shard_id`")  # noqa: E501

        path_params = {}
        if 'shard_id' in local_var_params:
            path_params['shardID'] = local_var_params['shard_id']  # noqa: E501

        query_params = []
        if 'since' in local_var_params:
            query_params.append(('since', local_var_params['since']))  # noqa: E501

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501
        if 'accept_encoding' in local_var_params:
            header_params['Accept-Encoding'] = local_var_params['accept_encoding']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream', 'application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class Variable(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'links': 'VariableLinks',
        'id': 'str',
        'org_id': 'str',
        'name': 'str',
        'description': 'str',
        'selected': 'list[str]',
        'labels': 'list[Label]',
        'arguments': 'VariableProperties',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'links': 'links',
        'id': 'id',
        'org_id': 'orgID',
        'name': 'name',
        'description': 'description',
        'selected': 'selected',
        'labels': 'labels',
        'arguments': 'arguments',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, links=None, id=None, org_id=None, name=None, description=None, selected=None, labels=None, arguments=None, created_at=None, updated_at=None):  # noqa: E501,D401,D403
        """Variable - a model defined in OpenAPI."""  # noqa: E501
        self._links = None
        self._id = None
        self._org_id = None
        self._name = None
        self._description = None
        self._selected = None
        self._labels = None
        self._arguments = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if links is not None:
            self.links = links
        if id is not None:
            self.id = id
        self.org_id = org_id
        self.name = name
        if description is not None:
            self.description = description
        if selected is not None:
            self.selected = selected
        if labels is not None:
            self.labels = labels
        self.arguments = arguments
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def links(self):
        """Get the links of this Variable.

        :return: The links of this Variable.
        :rtype: VariableLinks
        """  # noqa: E501
        return self._links

    @links.setter
    def links(self, links):
        """Set the links of this Variable.

        :param links: The links of this Variable.
        :type: VariableLinks
        """  # noqa: E501
        self._links = links

    @property
    def id(self):
        """Get the id of this Variable.

        :return: The id of this Variable.
        :rtype: str
        """  # noqa: E501
        return self._id

    @id.setter
    def id(self, id):
        """Set the id of this Variable.

        :param id: The id of this Variable.
        :type: str
        """  # noqa: E501
        self._id = id

    @property
    def org_id(self):
        """Get the org_id of this Variable.

        :return: The org_id of this Variable.
        :rtype: str
        """  # noqa: E501
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Set the org_id of this Variable.

        :param org_id: The org_id of this Variable.
        :type: str
        """  # noqa: E501
        if org_id is None:
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501
        self._org_id = org_id

    @property
    def name(self):
        """Get the name of this Variable.

        :return: The name of this Variable.
        :rtype: str
        """  # noqa: E501
        return self._name

    @name.setter
    def name(self, name):
        """Set the name of this Variable.

        :param name: The name of this Variable.
        :type: str
        """  # noqa: E501
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        self._name = name

    @property
    def description(self):
        """Get the description of this Variable.

        :return: The description of this Variable.
        :rtype: str
        """  # noqa: E501
        return self._description

    @description.setter
    def description(self, description):
        """Set the description of this Variable.

        :param description: The description of this Variable.
        :type: str
        """  # noqa: E501
        self._description = description

    @property
    def selected(self):
        """Get the selected of this Variable.

        :return: The selected of this Variable.
        :rtype: list[str]
        """  # noqa: E501
        return self._selected

    @selected.setter
    def selected(self, selected):
        """Set the selected of this Variable.

        :param selected: The selected of this Variable.
        :type: list[str]
        """  # noqa: E501
        self._selected = selected

    @property
    def labels(self):
        """Get the labels of this Variable.

        :return: The labels of this Variable.
        :rtype: list[Label]
        """  # noqa: E501
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Set the labels of this Variable.

        :param labels: The labels of this Variable.
        :type: list[Label]
        """  # noqa: E501
        self._labels = labels

    @property
    def arguments(self):
        """Get the arguments of this Variable.

        :return: The arguments of this Variable.
        :rtype: VariableProperties
        """  # noqa: E501
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Set the arguments of this Variable.

        :param arguments: The arguments of this Variable.
        :type: VariableProperties
        """  # noqa: E501
        if arguments is None:
            raise ValueError("Invalid value for `arguments`, must not be `None`")  # noqa: E501
        self._arguments = arguments

    @property
    def created_at(self):
        """Get the created_at of this Variable.

        :return: The created_at of this Variable.
        :rtype: datetime
        """  # noqa: E501
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Set the created_at of this Variable.

        :param created_at: The created_at of this Variable.
        :type: datetime
        """  # noqa: E501
        self._created_at = created_at

    @property
    def updated_at(self):
        """Get the updated_at of this Variable.

        :return: The updated_at of this Variable.
        :rtype: datetime
        """  # noqa: E501
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Set the updated_at of this Variable.

        :param updated_at: The updated_at of this Variable.
        :type: datetime
        """  # noqa: E501
        self._updated_at = updated_at

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, Variable):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from influxdb_client.service._base_service import _BaseService


class AuthorizationsService(_BaseService):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):  # noqa: E501,D401,D403
        """AuthorizationsService - a operation defined in OpenAPI."""
        super().__init__(api_client)

    def delete_authorizations_id(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        """Delete an authorization.

        Deletes an authorization.  Use the endpoint to delete an API token.  If you want to disable an API token instead of delete it, [update the authorization's status to `inactive`](#operation/PatchAuthorizationsID).
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_authorizations_id(auth_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: An authorization ID. Specifies the authorization to delete. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_authorizations_id_with_http_info(auth_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_authorizations_id_with_http_info(auth_id, **kwargs)  # noqa: E501
            return data

    def delete_authorizations_id_with_http_info(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        """Delete an authorization.

        Deletes an authorization.  Use the endpoint to delete an API token.  If you want to disable an API token instead of delete it, [update the authorization's status to `inactive`](#operation/PatchAuthorizationsID).
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_authorizations_id_with_http_info(auth_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: An authorization ID. Specifies the authorization to delete. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._delete_authorizations_id_prepare(auth_id, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/authorizations/{authID}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def delete_authorizations_id_async(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        """Delete an authorization.

        Deletes an authorization.  Use the endpoint to delete an API token.  If you want to disable an API token instead of delete it, [update the authorization's status to `inactive`](#operation/PatchAuthorizationsID).
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str auth_id: An authorization ID. Specifies the authorization to delete. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._delete_authorizations_id_prepare(auth_id, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/authorizations/{authID}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _delete_authorizations_id_prepare(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['auth_id', 'zap_trace_span']  # noqa: E501
        self._check_operation_params('delete_authorizations_id', all_params, local_var_params)
        # verify the required parameter 'auth_id' is set
        if ('auth_id' not in local_var_params or
                local_var_params['auth_id'] is None):
            raise ValueError("Missing the required parameter `auth_id` when calling `delete_authorizations_id`")  # noqa: E501

        path_params = {}
        if 'auth_id' in local_var_params:
            path_params['authID'] = local_var_params['auth_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def get_authorizations(self, **kwargs):  # noqa: E501,D401,D403
        """List authorizations.

        Lists authorizations.  To limit which authorizations are returned, pass query parameters in your request. If no query parameters are passed, InfluxDB returns all authorizations.  #### InfluxDB Cloud  - InfluxDB Cloud doesn't expose [API token](https://docs.influxdata.com/influxdb/latest/reference/glossary/#token)   values in `GET /api/v2/authorizations` responses;   returns `token: redacted` for all authorizations.  #### Required permissions  To retrieve an authorization, the request must use an API token that has the following permissions:  - `read-authorizations` - `read-user` for the user that the authorization is scoped to  #### Related guides  - [View tokens](https://docs.influxdata.com/influxdb/latest/security/tokens/view-tokens/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_authorizations(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :param str user_id: A user ID. Only returns authorizations scoped to the specified [user](https://docs.influxdata.com/influxdb/latest/reference/glossary/#user).
        :param str user: A user name. Only returns authorizations scoped to the specified [user](https://docs.influxdata.com/influxdb/latest/reference/glossary/#user).
        :param str org_id: An organization ID. Only returns authorizations that belong to the specified [organization](https://docs.influxdata.com/influxdb/latest/reference/glossary/#organization).
        :param str org: An organization name. Only returns authorizations that belong to the specified [organization](https://docs.influxdata.com/influxdb/latest/reference/glossary/#organization).
        :param str token: An API [token](https://docs.influxdata.com/influxdb/latest/reference/glossary/#token) value. Specifies an authorization by its `token` property value and returns the authorization.  #### InfluxDB OSS  - Doesn't support this parameter. InfluxDB OSS ignores the `token=` parameter,   applies other parameters, and then returns the result.  #### Limitations  - The parameter is non-repeatable. If you specify more than one,   only the first one is used. If a resource with the specified   property value doesn't exist, then the response body contains an empty list.
        :return: Authorizations
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_authorizations_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_authorizations_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_authorizations_with_http_info(self, **kwargs):  # noqa: E501,D401,D403
        """List authorizations.

        Lists authorizations.  To limit which authorizations are returned, pass query parameters in your request. If no query parameters are passed, InfluxDB returns all authorizations.  #### InfluxDB Cloud  - InfluxDB Cloud doesn't expose [API token](https://docs.influxdata.com/influxdb/latest/reference/glossary/#token)   values in `GET /api/v2/authorizations` responses;   returns `token: redacted` for all authorizations.  #### Required permissions  To retrieve an authorization, the request must use an API token that has the following permissions:  - `read-authorizations` - `read-user` for the user that the authorization is scoped to  #### Related guides  - [View tokens](https://docs.influxdata.com/influxdb/latest/security/tokens/view-tokens/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_authorizations_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :param str user_id: A user ID. Only returns authorizations scoped to the specified [user](https://docs.influxdata.com/influxdb/latest/reference/glossary/#user).
        :param str user: A user name. Only returns authorizations scoped to the specified [user](https://docs.influxdata.com/influxdb/latest/reference/glossary/#user).
        :param str org_id: An organization ID. Only returns authorizations that belong to the specified [organization](https://docs.influxdata.com/influxdb/latest/reference/glossary/#organization).
        :param str org: An organization name. Only returns authorizations that belong to the specified [organization](https://docs.influxdata.com/influxdb/latest/reference/glossary/#organization).
        :param str token: An API [token](https://docs.influxdata.com/influxdb/latest/reference/glossary/#token) value. Specifies an authorization by its `token` property value and returns the authorization.  #### InfluxDB OSS  - Doesn't support this parameter. InfluxDB OSS ignores the `token=` parameter,   applies other parameters, and then returns the result.  #### Limitations  - The parameter is non-repeatable. If you specify more than one,   only the first one is used. If a resource with the specified   property value doesn't exist, then the response body contains an empty list.
        :return: Authorizations
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_authorizations_prepare(**kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/authorizations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorizations',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_authorizations_async(self, **kwargs):  # noqa: E501,D401,D403
        """List authorizations.

        Lists authorizations.  To limit which authorizations are returned, pass query parameters in your request. If no query parameters are passed, InfluxDB returns all authorizations.  #### InfluxDB Cloud  - InfluxDB Cloud doesn't expose [API token](https://docs.influxdata.com/influxdb/latest/reference/glossary/#token)   values in `GET /api/v2/authorizations` responses;   returns `token: redacted` for all authorizations.  #### Required permissions  To retrieve an authorization, the request must use an API token that has the following permissions:  - `read-authorizations` - `read-user` for the user that the authorization is scoped to  #### Related guides  - [View tokens](https://docs.influxdata.com/influxdb/latest/security/tokens/view-tokens/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :param str user_id: A user ID. Only returns authorizations scoped to the specified [user](https://docs.influxdata.com/influxdb/latest/reference/glossary/#user).
        :param str user: A user name. Only returns authorizations scoped to the specified [user](https://docs.influxdata.com/influxdb/latest/reference/glossary/#user).
        :param str org_id: An organization ID. Only returns authorizations that belong to the specified [organization](https://docs.influxdata.com/influxdb/latest/reference/glossary/#organization).
        :param str org: An organization name. Only returns authorizations that belong to the specified [organization](https://docs.influxdata.com/influxdb/latest/reference/glossary/#organization).
        :param str token: An API [token](https://docs.influxdata.com/influxdb/latest/reference/glossary/#token) value. Specifies an authorization by its `token` property value and returns the authorization.  #### InfluxDB OSS  - Doesn't support this parameter. InfluxDB OSS ignores the `token=` parameter,   applies other parameters, and then returns the result.  #### Limitations  - The parameter is non-repeatable. If you specify more than one,   only the first one is used. If a resource with the specified   property value doesn't exist, then the response body contains an empty list.
        :return: Authorizations
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_authorizations_prepare(**kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/authorizations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorizations',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_authorizations_prepare(self, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['zap_trace_span', 'user_id', 'user', 'org_id', 'org', 'token']  # noqa: E501
        self._check_operation_params('get_authorizations', all_params, local_var_params)

        path_params = {}

        query_params = []
        if 'user_id' in local_var_params:
            query_params.append(('userID', local_var_params['user_id']))  # noqa: E501
        if 'user' in local_var_params:
            query_params.append(('user', local_var_params['user']))  # noqa: E501
        if 'org_id' in local_var_params:
            query_params.append(('orgID', local_var_params['org_id']))  # noqa: E501
        if 'org' in local_var_params:
            query_params.append(('org', local_var_params['org']))  # noqa: E501
        if 'token' in local_var_params:
            query_params.append(('token', local_var_params['token']))  # noqa: E501

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def get_authorizations_id(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        """Retrieve an authorization.

        Retrieves an authorization.  Use this endpoint to retrieve information about an API token, including the token's permissions and the user that the token is scoped to.  #### InfluxDB OSS  - InfluxDB OSS returns   [API token](https://docs.influxdata.com/influxdb/latest/reference/glossary/#token) values in authorizations. - If the request uses an _[operator token](https://docs.influxdata.com/influxdb/latest/security/tokens/#operator-token)_,   InfluxDB OSS returns authorizations for all organizations in the instance.  #### Related guides  - [View tokens](https://docs.influxdata.com/influxdb/latest/security/tokens/view-tokens/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_authorizations_id(auth_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: An authorization ID. Specifies the authorization to retrieve. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_authorizations_id_with_http_info(auth_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_authorizations_id_with_http_info(auth_id, **kwargs)  # noqa: E501
            return data

    def get_authorizations_id_with_http_info(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        """Retrieve an authorization.

        Retrieves an authorization.  Use this endpoint to retrieve information about an API token, including the token's permissions and the user that the token is scoped to.  #### InfluxDB OSS  - InfluxDB OSS returns   [API token](https://docs.influxdata.com/influxdb/latest/reference/glossary/#token) values in authorizations. - If the request uses an _[operator token](https://docs.influxdata.com/influxdb/latest/security/tokens/#operator-token)_,   InfluxDB OSS returns authorizations for all organizations in the instance.  #### Related guides  - [View tokens](https://docs.influxdata.com/influxdb/latest/security/tokens/view-tokens/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_authorizations_id_with_http_info(auth_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: An authorization ID. Specifies the authorization to retrieve. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_authorizations_id_prepare(auth_id, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/authorizations/{authID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorization',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_authorizations_id_async(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        """Retrieve an authorization.

        Retrieves an authorization.  Use this endpoint to retrieve information about an API token, including the token's permissions and the user that the token is scoped to.  #### InfluxDB OSS  - InfluxDB OSS returns   [API token](https://docs.influxdata.com/influxdb/latest/reference/glossary/#token) values in authorizations. - If the request uses an _[operator token](https://docs.influxdata.com/influxdb/latest/security/tokens/#operator-token)_,   InfluxDB OSS returns authorizations for all organizations in the instance.  #### Related guides  - [View tokens](https://docs.influxdata.com/influxdb/latest/security/tokens/view-tokens/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str auth_id: An authorization ID. Specifies the authorization to retrieve. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_authorizations_id_prepare(auth_id, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/authorizations/{authID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorization',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_authorizations_id_prepare(self, auth_id, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['auth_id', 'zap_trace_span']  # noqa: E501
        self._check_operation_params('get_authorizations_id', all_params, local_var_params)
        # verify the required parameter 'auth_id' is set
        if ('auth_id' not in local_var_params or
                local_var_params['auth_id'] is None):
            raise ValueError("Missing the required parameter `auth_id` when calling `get_authorizations_id`")  # noqa: E501

        path_params = {}
        if 'auth_id' in local_var_params:
            path_params['authID'] = local_var_params['auth_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def patch_authorizations_id(self, auth_id, authorization_update_request, **kwargs):  # noqa: E501,D401,D403
        """Update an API token to be active or inactive.

        Updates an authorization.  Use this endpoint to set an API token's status to be _active_ or _inactive_. InfluxDB rejects requests that use inactive API tokens.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_authorizations_id(auth_id, authorization_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: An authorization ID. Specifies the authorization to update. (required)
        :param AuthorizationUpdateRequest authorization_update_request: In the request body, provide the authorization properties to update. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.patch_authorizations_id_with_http_info(auth_id, authorization_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.patch_authorizations_id_with_http_info(auth_id, authorization_update_request, **kwargs)  # noqa: E501
            return data

    def patch_authorizations_id_with_http_info(self, auth_id, authorization_update_request, **kwargs):  # noqa: E501,D401,D403
        """Update an API token to be active or inactive.

        Updates an authorization.  Use this endpoint to set an API token's status to be _active_ or _inactive_. InfluxDB rejects requests that use inactive API tokens.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_authorizations_id_with_http_info(auth_id, authorization_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_id: An authorization ID. Specifies the authorization to update. (required)
        :param AuthorizationUpdateRequest authorization_update_request: In the request body, provide the authorization properties to update. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._patch_authorizations_id_prepare(auth_id, authorization_update_request, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/authorizations/{authID}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorization',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def patch_authorizations_id_async(self, auth_id, authorization_update_request, **kwargs):  # noqa: E501,D401,D403
        """Update an API token to be active or inactive.

        Updates an authorization.  Use this endpoint to set an API token's status to be _active_ or _inactive_. InfluxDB rejects requests that use inactive API tokens.
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str auth_id: An authorization ID. Specifies the authorization to update. (required)
        :param AuthorizationUpdateRequest authorization_update_request: In the request body, provide the authorization properties to update. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._patch_authorizations_id_prepare(auth_id, authorization_update_request, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/authorizations/{authID}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorization',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _patch_authorizations_id_prepare(self, auth_id, authorization_update_request, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['auth_id', 'authorization_update_request', 'zap_trace_span']  # noqa: E501
        self._check_operation_params('patch_authorizations_id', all_params, local_var_params)
        # verify the required parameter 'auth_id' is set
        if ('auth_id' not in local_var_params or
                local_var_params['auth_id'] is None):
            raise ValueError("Missing the required parameter `auth_id` when calling `patch_authorizations_id`")  # noqa: E501
        # verify the required parameter 'authorization_update_request' is set
        if ('authorization_update_request' not in local_var_params or
                local_var_params['authorization_update_request'] is None):
            raise ValueError("Missing the required parameter `authorization_update_request` when calling `patch_authorizations_id`")  # noqa: E501

        path_params = {}
        if 'auth_id' in local_var_params:
            path_params['authID'] = local_var_params['auth_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        body_params = None
        if 'authorization_update_request' in local_var_params:
            body_params = local_var_params['authorization_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def post_authorizations(self, authorization_post_request, **kwargs):  # noqa: E501,D401,D403
        """Create an authorization.

        Creates an authorization and returns the authorization with the generated API [token](https://docs.influxdata.com/influxdb/latest/reference/glossary/#token).  Use this endpoint to create an authorization, which generates an API token with permissions to `read` or `write` to a specific resource or `type` of resource. The API token is the authorization's `token` property value.  To follow best practices for secure API token generation and retrieval, InfluxDB enforces access restrictions on API tokens.    - InfluxDB allows access to the API token value immediately after the authorization is created.   - You can’t change access (read/write) permissions for an API token after it’s created.   - Tokens stop working when the user who created the token is deleted.  We recommend the following for managing your tokens:    - Create a generic user to create and manage tokens for writing data.   - Store your tokens in a secure password vault for future access.  #### Required permissions  - `write-authorizations` - `write-user` for the user that the authorization is scoped to  #### Related guides  - [Create a token](https://docs.influxdata.com/influxdb/latest/security/tokens/create-token/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_authorizations(authorization_post_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AuthorizationPostRequest authorization_post_request: The authorization to create. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_authorizations_with_http_info(authorization_post_request, **kwargs)  # noqa: E501
        else:
            (data) = self.post_authorizations_with_http_info(authorization_post_request, **kwargs)  # noqa: E501
            return data

    def post_authorizations_with_http_info(self, authorization_post_request, **kwargs):  # noqa: E501,D401,D403
        """Create an authorization.

        Creates an authorization and returns the authorization with the generated API [token](https://docs.influxdata.com/influxdb/latest/reference/glossary/#token).  Use this endpoint to create an authorization, which generates an API token with permissions to `read` or `write` to a specific resource or `type` of resource. The API token is the authorization's `token` property value.  To follow best practices for secure API token generation and retrieval, InfluxDB enforces access restrictions on API tokens.    - InfluxDB allows access to the API token value immediately after the authorization is created.   - You can’t change access (read/write) permissions for an API token after it’s created.   - Tokens stop working when the user who created the token is deleted.  We recommend the following for managing your tokens:    - Create a generic user to create and manage tokens for writing data.   - Store your tokens in a secure password vault for future access.  #### Required permissions  - `write-authorizations` - `write-user` for the user that the authorization is scoped to  #### Related guides  - [Create a token](https://docs.influxdata.com/influxdb/latest/security/tokens/create-token/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_authorizations_with_http_info(authorization_post_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AuthorizationPostRequest authorization_post_request: The authorization to create. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._post_authorizations_prepare(authorization_post_request, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/authorizations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorization',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def post_authorizations_async(self, authorization_post_request, **kwargs):  # noqa: E501,D401,D403
        """Create an authorization.

        Creates an authorization and returns the authorization with the generated API [token](https://docs.influxdata.com/influxdb/latest/reference/glossary/#token).  Use this endpoint to create an authorization, which generates an API token with permissions to `read` or `write` to a specific resource or `type` of resource. The API token is the authorization's `token` property value.  To follow best practices for secure API token generation and retrieval, InfluxDB enforces access restrictions on API tokens.    - InfluxDB allows access to the API token value immediately after the authorization is created.   - You can’t change access (read/write) permissions for an API token after it’s created.   - Tokens stop working when the user who created the token is deleted.  We recommend the following for managing your tokens:    - Create a generic user to create and manage tokens for writing data.   - Store your tokens in a secure password vault for future access.  #### Required permissions  - `write-authorizations` - `write-user` for the user that the authorization is scoped to  #### Related guides  - [Create a token](https://docs.influxdata.com/influxdb/latest/security/tokens/create-token/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param AuthorizationPostRequest authorization_post_request: The authorization to create. (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Authorization
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._post_authorizations_prepare(authorization_post_request, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/authorizations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Authorization',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _post_authorizations_prepare(self, authorization_post_request, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['authorization_post_request', 'zap_trace_span']  # noqa: E501
        self._check_operation_params('post_authorizations', all_params, local_var_params)
        # verify the required parameter 'authorization_post_request' is set
        if ('authorization_post_request' not in local_var_params or
                local_var_params['authorization_post_request'] is None):
            raise ValueError("Missing the required parameter `authorization_post_request` when calling `post_authorizations`")  # noqa: E501

        path_params = {}

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        body_params = None
        if 'authorization_post_request' in local_var_params:
            body_params = local_var_params['authorization_post_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class Replication(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'org_id': 'str',
        'remote_id': 'str',
        'local_bucket_id': 'str',
        'remote_bucket_id': 'str',
        'remote_bucket_name': 'str',
        'max_queue_size_bytes': 'int',
        'current_queue_size_bytes': 'int',
        'remaining_bytes_to_be_synced': 'int',
        'latest_response_code': 'int',
        'latest_error_message': 'str',
        'drop_non_retryable_data': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'org_id': 'orgID',
        'remote_id': 'remoteID',
        'local_bucket_id': 'localBucketID',
        'remote_bucket_id': 'remoteBucketID',
        'remote_bucket_name': 'remoteBucketName',
        'max_queue_size_bytes': 'maxQueueSizeBytes',
        'current_queue_size_bytes': 'currentQueueSizeBytes',
        'remaining_bytes_to_be_synced': 'remainingBytesToBeSynced',
        'latest_response_code': 'latestResponseCode',
        'latest_error_message': 'latestErrorMessage',
        'drop_non_retryable_data': 'dropNonRetryableData'
    }

    def __init__(self, id=None, name=None, description=None, org_id=None, remote_id=None, local_bucket_id=None, remote_bucket_id=None, remote_bucket_name=None, max_queue_size_bytes=None, current_queue_size_bytes=None, remaining_bytes_to_be_synced=None, latest_response_code=None, latest_error_message=None, drop_non_retryable_data=None):  # noqa: E501,D401,D403
        """Replication - a model defined in OpenAPI."""  # noqa: E501
        self._id = None
        self._name = None
        self._description = None
        self._org_id = None
        self._remote_id = None
        self._local_bucket_id = None
        self._remote_bucket_id = None
        self._remote_bucket_name = None
        self._max_queue_size_bytes = None
        self._current_queue_size_bytes = None
        self._remaining_bytes_to_be_synced = None
        self._latest_response_code = None
        self._latest_error_message = None
        self._drop_non_retryable_data = None
        self.discriminator = None

        self.id = id
        self.name = name
        if description is not None:
            self.description = description
        self.org_id = org_id
        self.remote_id = remote_id
        self.local_bucket_id = local_bucket_id
        if remote_bucket_id is not None:
            self.remote_bucket_id = remote_bucket_id
        if remote_bucket_name is not None:
            self.remote_bucket_name = remote_bucket_name
        self.max_queue_size_bytes = max_queue_size_bytes
        if current_queue_size_bytes is not None:
            self.current_queue_size_bytes = current_queue_size_bytes
        if remaining_bytes_to_be_synced is not None:
            self.remaining_bytes_to_be_synced = remaining_bytes_to_be_synced
        if latest_response_code is not None:
            self.latest_response_code = latest_response_code
        if latest_error_message is not None:
            self.latest_error_message = latest_error_message
        if drop_non_retryable_data is not None:
            self.drop_non_retryable_data = drop_non_retryable_data

    @property
    def id(self):
        """Get the id of this Replication.

        :return: The id of this Replication.
        :rtype: str
        """  # noqa: E501
        return self._id

    @id.setter
    def id(self, id):
        """Set the id of this Replication.

        :param id: The id of this Replication.
        :type: str
        """  # noqa: E501
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        self._id = id

    @property
    def name(self):
        """Get the name of this Replication.

        :return: The name of this Replication.
        :rtype: str
        """  # noqa: E501
        return self._name

    @name.setter
    def name(self, name):
        """Set the name of this Replication.

        :param name: The name of this Replication.
        :type: str
        """  # noqa: E501
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        self._name = name

    @property
    def description(self):
        """Get the description of this Replication.

        :return: The description of this Replication.
        :rtype: str
        """  # noqa: E501
        return self._description

    @description.setter
    def description(self, description):
        """Set the description of this Replication.

        :param description: The description of this Replication.
        :type: str
        """  # noqa: E501
        self._description = description

    @property
    def org_id(self):
        """Get the org_id of this Replication.

        :return: The org_id of this Replication.
        :rtype: str
        """  # noqa: E501
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Set the org_id of this Replication.

        :param org_id: The org_id of this Replication.
        :type: str
        """  # noqa: E501
        if org_id is None:
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501
        self._org_id = org_id

    @property
    def remote_id(self):
        """Get the remote_id of this Replication.

        :return: The remote_id of this Replication.
        :rtype: str
        """  # noqa: E501
        return self._remote_id

    @remote_id.setter
    def remote_id(self, remote_id):
        """Set the remote_id of this Replication.

        :param remote_id: The remote_id of this Replication.
        :type: str
        """  # noqa: E501
        if remote_id is None:
            raise ValueError("Invalid value for `remote_id`, must not be `None`")  # noqa: E501
        self._remote_id = remote_id

    @property
    def local_bucket_id(self):
        """Get the local_bucket_id of this Replication.

        :return: The local_bucket_id of this Replication.
        :rtype: str
        """  # noqa: E501
        return self._local_bucket_id

    @local_bucket_id.setter
    def local_bucket_id(self, local_bucket_id):
        """Set the local_bucket_id of this Replication.

        :param local_bucket_id: The local_bucket_id of this Replication.
        :type: str
        """  # noqa: E501
        if local_bucket_id is None:
            raise ValueError("Invalid value for `local_bucket_id`, must not be `None`")  # noqa: E501
        self._local_bucket_id = local_bucket_id

    @property
    def remote_bucket_id(self):
        """Get the remote_bucket_id of this Replication.

        :return: The remote_bucket_id of this Replication.
        :rtype: str
        """  # noqa: E501
        return self._remote_bucket_id

    @remote_bucket_id.setter
    def remote_bucket_id(self, remote_bucket_id):
        """Set the remote_bucket_id of this Replication.

        :param remote_bucket_id: The remote_bucket_id of this Replication.
        :type: str
        """  # noqa: E501
        self._remote_bucket_id = remote_bucket_id

    @property
    def remote_bucket_name(self):
        """Get the remote_bucket_name of this Replication.

        :return: The remote_bucket_name of this Replication.
        :rtype: str
        """  # noqa: E501
        return self._remote_bucket_name

    @remote_bucket_name.setter
    def remote_bucket_name(self, remote_bucket_name):
        """Set the remote_bucket_name of this Replication.

        :param remote_bucket_name: The remote_bucket_name of this Replication.
        :type: str
        """  # noqa: E501
        self._remote_bucket_name = remote_bucket_name

    @property
    def max_queue_size_bytes(self):
        """Get the max_queue_size_bytes of this Replication.

        :return: The max_queue_size_bytes of this Replication.
        :rtype: int
        """  # noqa: E501
        return self._max_queue_size_bytes

    @max_queue_size_bytes.setter
    def max_queue_size_bytes(self, max_queue_size_bytes):
        """Set the max_queue_size_bytes of this Replication.

        :param max_queue_size_bytes: The max_queue_size_bytes of this Replication.
        :type: int
        """  # noqa: E501
        if max_queue_size_bytes is None:
            raise ValueError("Invalid value for `max_queue_size_bytes`, must not be `None`")  # noqa: E501
        self._max_queue_size_bytes = max_queue_size_bytes

    @property
    def current_queue_size_bytes(self):
        """Get the current_queue_size_bytes of this Replication.

        :return: The current_queue_size_bytes of this Replication.
        :rtype: int
        """  # noqa: E501
        return self._current_queue_size_bytes

    @current_queue_size_bytes.setter
    def current_queue_size_bytes(self, current_queue_size_bytes):
        """Set the current_queue_size_bytes of this Replication.

        :param current_queue_size_bytes: The current_queue_size_bytes of this Replication.
        :type: int
        """  # noqa: E501
        self._current_queue_size_bytes = current_queue_size_bytes

    @property
    def remaining_bytes_to_be_synced(self):
        """Get the remaining_bytes_to_be_synced of this Replication.

        :return: The remaining_bytes_to_be_synced of this Replication.
        :rtype: int
        """  # noqa: E501
        return self._remaining_bytes_to_be_synced

    @remaining_bytes_to_be_synced.setter
    def remaining_bytes_to_be_synced(self, remaining_bytes_to_be_synced):
        """Set the remaining_bytes_to_be_synced of this Replication.

        :param remaining_bytes_to_be_synced: The remaining_bytes_to_be_synced of this Replication.
        :type: int
        """  # noqa: E501
        self._remaining_bytes_to_be_synced = remaining_bytes_to_be_synced

    @property
    def latest_response_code(self):
        """Get the latest_response_code of this Replication.

        :return: The latest_response_code of this Replication.
        :rtype: int
        """  # noqa: E501
        return self._latest_response_code

    @latest_response_code.setter
    def latest_response_code(self, latest_response_code):
        """Set the latest_response_code of this Replication.

        :param latest_response_code: The latest_response_code of this Replication.
        :type: int
        """  # noqa: E501
        self._latest_response_code = latest_response_code

    @property
    def latest_error_message(self):
        """Get the latest_error_message of this Replication.

        :return: The latest_error_message of this Replication.
        :rtype: str
        """  # noqa: E501
        return self._latest_error_message

    @latest_error_message.setter
    def latest_error_message(self, latest_error_message):
        """Set the latest_error_message of this Replication.

        :param latest_error_message: The latest_error_message of this Replication.
        :type: str
        """  # noqa: E501
        self._latest_error_message = latest_error_message

    @property
    def drop_non_retryable_data(self):
        """Get the drop_non_retryable_data of this Replication.

        :return: The drop_non_retryable_data of this Replication.
        :rtype: bool
        """  # noqa: E501
        return self._drop_non_retryable_data

    @drop_non_retryable_data.setter
    def drop_non_retryable_data(self, drop_non_retryable_data):
        """Set the drop_non_retryable_data of this Replication.

        :param drop_non_retryable_data: The drop_non_retryable_data of this Replication.
        :type: bool
        """  # noqa: E501
        self._drop_non_retryable_data = drop_non_retryable_data

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, Replication):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class TemplateSummarySummaryVariables(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'kind': 'TemplateKind',
        'template_meta_name': 'str',
        'id': 'str',
        'org_id': 'str',
        'name': 'str',
        'description': 'str',
        'arguments': 'VariableProperties',
        'label_associations': 'list[TemplateSummaryLabel]',
        'env_references': 'list[object]'
    }

    attribute_map = {
        'kind': 'kind',
        'template_meta_name': 'templateMetaName',
        'id': 'id',
        'org_id': 'orgID',
        'name': 'name',
        'description': 'description',
        'arguments': 'arguments',
        'label_associations': 'labelAssociations',
        'env_references': 'envReferences'
    }

    def __init__(self, kind=None, template_meta_name=None, id=None, org_id=None, name=None, description=None, arguments=None, label_associations=None, env_references=None):  # noqa: E501,D401,D403
        """TemplateSummarySummaryVariables - a model defined in OpenAPI."""  # noqa: E501
        self._kind = None
        self._template_meta_name = None
        self._id = None
        self._org_id = None
        self._name = None
        self._description = None
        self._arguments = None
        self._label_associations = None
        self._env_references = None
        self.discriminator = None

        if kind is not None:
            self.kind = kind
        if template_meta_name is not None:
            self.template_meta_name = template_meta_name
        if id is not None:
            self.id = id
        if org_id is not None:
            self.org_id = org_id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if arguments is not None:
            self.arguments = arguments
        if label_associations is not None:
            self.label_associations = label_associations
        if env_references is not None:
            self.env_references = env_references

    @property
    def kind(self):
        """Get the kind of this TemplateSummarySummaryVariables.

        :return: The kind of this TemplateSummarySummaryVariables.
        :rtype: TemplateKind
        """  # noqa: E501
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Set the kind of this TemplateSummarySummaryVariables.

        :param kind: The kind of this TemplateSummarySummaryVariables.
        :type: TemplateKind
        """  # noqa: E501
        self._kind = kind

    @property
    def template_meta_name(self):
        """Get the template_meta_name of this TemplateSummarySummaryVariables.

        :return: The template_meta_name of this TemplateSummarySummaryVariables.
        :rtype: str
        """  # noqa: E501
        return self._template_meta_name

    @template_meta_name.setter
    def template_meta_name(self, template_meta_name):
        """Set the template_meta_name of this TemplateSummarySummaryVariables.

        :param template_meta_name: The template_meta_name of this TemplateSummarySummaryVariables.
        :type: str
        """  # noqa: E501
        self._template_meta_name = template_meta_name

    @property
    def id(self):
        """Get the id of this TemplateSummarySummaryVariables.

        :return: The id of this TemplateSummarySummaryVariables.
        :rtype: str
        """  # noqa: E501
        return self._id

    @id.setter
    def id(self, id):
        """Set the id of this TemplateSummarySummaryVariables.

        :param id: The id of this TemplateSummarySummaryVariables.
        :type: str
        """  # noqa: E501
        self._id = id

    @property
    def org_id(self):
        """Get the org_id of this TemplateSummarySummaryVariables.

        :return: The org_id of this TemplateSummarySummaryVariables.
        :rtype: str
        """  # noqa: E501
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Set the org_id of this TemplateSummarySummaryVariables.

        :param org_id: The org_id of this TemplateSummarySummaryVariables.
        :type: str
        """  # noqa: E501
        self._org_id = org_id

    @property
    def name(self):
        """Get the name of this TemplateSummarySummaryVariables.

        :return: The name of this TemplateSummarySummaryVariables.
        :rtype: str
        """  # noqa: E501
        return self._name

    @name.setter
    def name(self, name):
        """Set the name of this TemplateSummarySummaryVariables.

        :param name: The name of this TemplateSummarySummaryVariables.
        :type: str
        """  # noqa: E501
        self._name = name

    @property
    def description(self):
        """Get the description of this TemplateSummarySummaryVariables.

        :return: The description of this TemplateSummarySummaryVariables.
        :rtype: str
        """  # noqa: E501
        return self._description

    @description.setter
    def description(self, description):
        """Set the description of this TemplateSummarySummaryVariables.

        :param description: The description of this TemplateSummarySummaryVariables.
        :type: str
        """  # noqa: E501
        self._description = description

    @property
    def arguments(self):
        """Get the arguments of this TemplateSummarySummaryVariables.

        :return: The arguments of this TemplateSummarySummaryVariables.
        :rtype: VariableProperties
        """  # noqa: E501
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Set the arguments of this TemplateSummarySummaryVariables.

        :param arguments: The arguments of this TemplateSummarySummaryVariables.
        :type: VariableProperties
        """  # noqa: E501
        self._arguments = arguments

    @property
    def label_associations(self):
        """Get the label_associations of this TemplateSummarySummaryVariables.

        :return: The label_associations of this TemplateSummarySummaryVariables.
        :rtype: list[TemplateSummaryLabel]
        """  # noqa: E501
        return self._label_associations

    @label_associations.setter
    def label_associations(self, label_associations):
        """Set the label_associations of this TemplateSummarySummaryVariables.

        :param label_associations: The label_associations of this TemplateSummarySummaryVariables.
        :type: list[TemplateSummaryLabel]
        """  # noqa: E501
        self._label_associations = label_associations

    @property
    def env_references(self):
        """Get the env_references of this TemplateSummarySummaryVariables.

        :return: The env_references of this TemplateSummarySummaryVariables.
        :rtype: list[object]
        """  # noqa: E501
        return self._env_references

    @env_references.setter
    def env_references(self, env_references):
        """Set the env_references of this TemplateSummarySummaryVariables.

        :param env_references: The env_references of this TemplateSummarySummaryVariables.
        :type: list[object]
        """  # noqa: E501
        self._env_references = env_references

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, TemplateSummarySummaryVariables):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



"""
Helpers classes to make easier use the client in multiprocessing environment.

For more information how the multiprocessing works see Python's
`reference docs <https://docs.python.org/3/library/multiprocessing.html>`_.
"""
import logging
import multiprocessing

from influxdb_client import InfluxDBClient, WriteOptions
from influxdb_client.client.exceptions import InfluxDBError

logger = logging.getLogger('influxdb_client.client.util.multiprocessing_helper')


def _success_callback(conf: (str, str, str), data: str):
    """Successfully writen batch."""
    logger.debug(f"Written batch: {conf}, data: {data}")


def _error_callback(conf: (str, str, str), data: str, exception: InfluxDBError):
    """Unsuccessfully writen batch."""
    logger.debug(f"Cannot write batch: {conf}, data: {data} due: {exception}")


def _retry_callback(conf: (str, str, str), data: str, exception: InfluxDBError):
    """Retryable error."""
    logger.debug(f"Retryable error occurs for batch: {conf}, data: {data} retry: {exception}")


class _PoisonPill:
    """To notify process to terminate."""

    pass


class MultiprocessingWriter(multiprocessing.Process):
    """
    The Helper class to write data into InfluxDB in independent OS process.

    Example:
        .. code-block:: python

            from influxdb_client import WriteOptions
            from influxdb_client.client.util.multiprocessing_helper import MultiprocessingWriter


            def main():
                writer = MultiprocessingWriter(url="http://localhost:8086", token="my-token", org="my-org",
                                               write_options=WriteOptions(batch_size=100))
                writer.start()

                for x in range(1, 1000):
                    writer.write(bucket="my-bucket", record=f"mem,tag=a value={x}i {x}")

                writer.__del__()


            if __name__ == '__main__':
                main()


    How to use with context_manager:
        .. code-block:: python

            from influxdb_client import WriteOptions
            from influxdb_client.client.util.multiprocessing_helper import MultiprocessingWriter


            def main():
                with MultiprocessingWriter(url="http://localhost:8086", token="my-token", org="my-org",
                                           write_options=WriteOptions(batch_size=100)) as writer:
                    for x in range(1, 1000):
                        writer.write(bucket="my-bucket", record=f"mem,tag=a value={x}i {x}")


            if __name__ == '__main__':
                main()


    How to handle batch events:
        .. code-block:: python

            from influxdb_client import WriteOptions
            from influxdb_client.client.exceptions import InfluxDBError
            from influxdb_client.client.util.multiprocessing_helper import MultiprocessingWriter


            class BatchingCallback(object):

                def success(self, conf: (str, str, str), data: str):
                    print(f"Written batch: {conf}, data: {data}")

                def error(self, conf: (str, str, str), data: str, exception: InfluxDBError):
                    print(f"Cannot write batch: {conf}, data: {data} due: {exception}")

                def retry(self, conf: (str, str, str), data: str, exception: InfluxDBError):
                    print(f"Retryable error occurs for batch: {conf}, data: {data} retry: {exception}")


            def main():
                callback = BatchingCallback()
                with MultiprocessingWriter(url="http://localhost:8086", token="my-token", org="my-org",
                                           success_callback=callback.success,
                                           error_callback=callback.error,
                                           retry_callback=callback.retry) as writer:

                    for x in range(1, 1000):
                        writer.write(bucket="my-bucket", record=f"mem,tag=a value={x}i {x}")


            if __name__ == '__main__':
                main()


    """

    __started__ = False
    __disposed__ = False

    def __init__(self, **kwargs) -> None:
        """
        Initialize defaults.

        For more information how to initialize the writer see the examples above.

        :param kwargs: arguments are passed into ``__init__`` function of ``InfluxDBClient`` and ``write_api``.
        """
        multiprocessing.Process.__init__(self)
        self.kwargs = kwargs
        self.client = None
        self.write_api = None
        self.queue_ = multiprocessing.Manager().Queue()

    def write(self, **kwargs) -> None:
        """
        Append time-series data into underlying queue.

        For more information how to pass arguments see the examples above.

        :param kwargs: arguments are passed into ``write`` function of ``WriteApi``
        :return: None
        """
        assert self.__disposed__ is False, 'Cannot write data: the writer is closed.'
        assert self.__started__ is True, 'Cannot write data: the writer is not started.'
        self.queue_.put(kwargs)

    def run(self):
        """Initialize ``InfluxDBClient`` and waits for data to writes into InfluxDB."""
        # Initialize Client and Write API
        self.client = InfluxDBClient(**self.kwargs)
        self.write_api = self.client.write_api(write_options=self.kwargs.get('write_options', WriteOptions()),
                                               success_callback=self.kwargs.get('success_callback', _success_callback),
                                               error_callback=self.kwargs.get('error_callback', _error_callback),
                                               retry_callback=self.kwargs.get('retry_callback', _retry_callback))
        # Infinite loop - until poison pill
        while True:
            next_record = self.queue_.get()
            if type(next_record) is _PoisonPill:
                # Poison pill means break the loop
                self.terminate()
                self.queue_.task_done()
                break
            self.write_api.write(**next_record)
            self.queue_.task_done()

    def start(self) -> None:
        """Start independent process for writing data into InfluxDB."""
        super().start()
        self.__started__ = True

    def terminate(self) -> None:
        """
        Cleanup resources in independent process.

        This function **cannot be used** to terminate the ``MultiprocessingWriter``.
        If you want to finish your writes please call: ``__del__``.
        """
        if self.write_api:
            logger.info("flushing data...")
            self.write_api.__del__()
            self.write_api = None
        if self.client:
            self.client.__del__()
            self.client = None
            logger.info("closed")

    def __enter__(self):
        """Enter the runtime context related to this object."""
        self.start()
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        """Exit the runtime context related to this object."""
        self.__del__()

    def __del__(self):
        """Dispose the client and write_api."""
        if self.__started__:
            self.queue_.put(_PoisonPill())
            self.queue_.join()
            self.join()
            self.queue_ = None
        self.__started__ = False
        self.__disposed__ = True
